@@ -87,12 +87,27 @@ helpMethods <- function(genericFunction) {
 	 	return(invisible())
 	}
 }
- 
+
+limmaUsersGuide <- function(view=TRUE)
+#	Find and optionally view limma User's Guide
+#	Gordon Smyth
+#	25 Oct 2004.
+{
+	f <- system.file("doc","usersguide.pdf",package="limma")
+	if(view) {
+		if(.Platform$OS.type == "windows") 
+			shell.exec(f)
+		else
+			system(paste(Sys.getenv("R_PDFVIEWER"),f,"&"))
+	}
+	return(f)
+}
+
 changeLog <- function(n=20)
 #	Write first n lines of limma changelog
 #	Gordon Smyth
-#	20 Sep 2004
+#	20 Sep 2004.  Last modified 30 Oct 2004.
 {
-	writeLines(readLines(system.file("doc/changelog.txt",package="limma"),n=20))
+	writeLines(readLines(system.file("doc","changelog.txt",package="limma"),n=n))
 }
 
